package
Version:
v0.2.0
Opens a new window with list of versions in this module.
Published: Jan 8, 2026
License: MIT
Opens a new window with license information.
Imports: 6
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Data struct {
Ref string `json:"ref"`
}
data represents the minimal structure needed to process a push event
Source Files
¶
Click to show internal directories.
Click to hide internal directories.